@@ -50,6 +50,7 @@ from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import ServicesTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import ServicesGrpcTransport
 from .transports.grpc_asyncio import ServicesGrpcAsyncIOTransport
+from .transports.rest import ServicesRestTransport
 
 
 class ServicesClientMeta(type):
@@ -63,6 +64,7 @@ class ServicesClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[ServicesTransport]]
     _transport_registry["grpc"] = ServicesGrpcTransport
     _transport_registry["grpc_asyncio"] = ServicesGrpcAsyncIOTransport
+    _transport_registry["rest"] = ServicesRestTransport
 
     def get_transport_class(
         cls,
@@ -465,6 +467,9 @@ class ServicesClient(metaclass=ServicesClientMeta):
             transport (Union[str, ServicesTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
+                NOTE: "rest" transport functionality is currently in a
+                beta state (preview). We welcome your feedback via an
+                issue in this library's source repository.
             client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
@@ -561,6 +566,13 @@ class ServicesClient(metaclass=ServicesClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import run_v2
 
             def sample_create_service():
@@ -705,6 +717,13 @@ class ServicesClient(metaclass=ServicesClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import run_v2
 
             def sample_get_service():
@@ -816,6 +835,13 @@ class ServicesClient(metaclass=ServicesClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import run_v2
 
             def sample_list_services():
@@ -935,6 +961,13 @@ class ServicesClient(metaclass=ServicesClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import run_v2
 
             def sample_update_service():
@@ -1056,6 +1089,13 @@ class ServicesClient(metaclass=ServicesClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import run_v2
 
             def sample_delete_service():
@@ -1180,6 +1220,13 @@ class ServicesClient(metaclass=ServicesClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import run_v2
             from google.iam.v1 import iam_policy_pb2  # type: ignore
 
@@ -1316,6 +1363,13 @@ class ServicesClient(metaclass=ServicesClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import run_v2
             from google.iam.v1 import iam_policy_pb2  # type: ignore
 
@@ -1454,6 +1508,13 @@ class ServicesClient(metaclass=ServicesClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import run_v2
             from google.iam.v1 import iam_policy_pb2  # type: ignore
 
@@ -1464,7 +1525,7 @@ class ServicesClient(metaclass=ServicesClientMeta):
                 # Initialize request argument(s)
                 request = iam_policy_pb2.TestIamPermissionsRequest(
                     resource="resource_value",
-                    permissions=['permissions_value_1', 'permissions_value_2'],
+                    permissions=['permissions_value1', 'permissions_value2'],
                 )
 
                 # Make the request
